package org.apache.bcel;

import java.io.IOException;
import org.apache.bcel.classfile.JavaClass;
import org.apache.bcel.util.ClassPath;
import org.apache.bcel.util.SyntheticRepository;

public abstract class Repository {
   private static org.apache.bcel.util.Repository repository = SyntheticRepository.getInstance();

   public static JavaClass addClass(JavaClass clazz) {
      JavaClass old = repository.findClass(clazz.getClassName());
      repository.storeClass(clazz);
      return old;
   }

   public static void clearCache() {
      repository.clear();
   }

   public static JavaClass[] getInterfaces(JavaClass clazz) throws ClassNotFoundException {
      return clazz.getAllInterfaces();
   }

   public static JavaClass[] getInterfaces(String className) throws ClassNotFoundException {
      return getInterfaces(lookupClass(className));
   }

   public static org.apache.bcel.util.Repository getRepository() {
      return repository;
   }

   public static JavaClass[] getSuperClasses(JavaClass clazz) throws ClassNotFoundException {
      return clazz.getSuperClasses();
   }

   public static JavaClass[] getSuperClasses(String className) throws ClassNotFoundException {
      return getSuperClasses(lookupClass(className));
   }

   public static boolean implementationOf(JavaClass clazz, JavaClass inter) throws ClassNotFoundException {
      return clazz.implementationOf(inter);
   }

   public static boolean implementationOf(JavaClass clazz, String inter) throws ClassNotFoundException {
      return implementationOf(clazz, lookupClass(inter));
   }

   public static boolean implementationOf(String clazz, JavaClass inter) throws ClassNotFoundException {
      return implementationOf(lookupClass(clazz), inter);
   }

   public static boolean implementationOf(String clazz, String inter) throws ClassNotFoundException {
      return implementationOf(lookupClass(clazz), lookupClass(inter));
   }

   public static boolean instanceOf(JavaClass clazz, JavaClass superclass) throws ClassNotFoundException {
      return clazz.instanceOf(superclass);
   }

   public static boolean instanceOf(JavaClass clazz, String superclass) throws ClassNotFoundException {
      return instanceOf(clazz, lookupClass(superclass));
   }

   public static boolean instanceOf(String clazz, JavaClass superclass) throws ClassNotFoundException {
      return instanceOf(lookupClass(clazz), superclass);
   }

   public static boolean instanceOf(String clazz, String superclass) throws ClassNotFoundException {
      return instanceOf(lookupClass(clazz), lookupClass(superclass));
   }

   public static JavaClass lookupClass(Class<?> clazz) throws ClassNotFoundException {
      return repository.loadClass(clazz);
   }

   public static JavaClass lookupClass(String className) throws ClassNotFoundException {
      return repository.loadClass(className);
   }

   public static ClassPath.ClassFile lookupClassFile(String className) {
      try {
         ClassPath path = repository.getClassPath();
         Throwable var2 = null;

         ClassPath.ClassFile var3;
         try {
            if (path == null) {
               var3 = null;
               return var3;
            }

            var3 = path.getClassFile(className);
         } catch (Throwable var14) {
            var2 = var14;
            throw var14;
         } finally {
            if (path != null) {
               if (var2 != null) {
                  try {
                     path.close();
                  } catch (Throwable var13) {
                     var2.addSuppressed(var13);
                  }
               } else {
                  path.close();
               }
            }

         }

         return var3;
      } catch (IOException var16) {
         return null;
      }
   }

   public static void removeClass(JavaClass clazz) {
      repository.removeClass(clazz);
   }

   public static void removeClass(String clazz) {
      repository.removeClass(repository.findClass(clazz));
   }

   public static void setRepository(org.apache.bcel.util.Repository rep) {
      repository = rep;
   }
}
